@@ -1,10 +1,10 @@
 # chart.py
 
 import os
-from src.models.object_def.a_field import AField
+from src.models._base_def import AField
 
 
-def creates_charts(charts, obj_dir):
+def creates_charts(charts, obj_dir) -> None:
     path = "{}/charts".format(obj_dir)
     if not os.path.exists(path.encode("utf-8")):
         os.makedirs(path.encode("utf-8"))
