@@ -1,7 +1,7 @@
 # init.py
 import os
 
-def init():
+def init() -> None:
     global FOLDER
     FOLDER = ""
     
